#include<stdio.h>
#include<stdlib.h>
#include<vector>
#include<queue>
#include<set>

struct Pad {
	int code;
	int steps;
};


class LadyLogic {
	
	int display, memory;
	char op;
	bool o;
	int steps;
	int target;
	
	Pad encode(int, int, char, bool, int);
	void decode(Pad);
	bool valid();
	bool visited(int);
	std::vector<bool> v;
	std::vector<char> options;
	std::queue<Pad> myq;
	std::set<int> mset;
	public:
	int eval(int, char, int);
	void generateSuccessors();
	void reset();
	void solve();
	bool finish();
	bool load();
};

void LadyLogic::reset() {
	mset.clear();
	while(!myq.empty()) myq.pop();
	steps = display = memory = 0;
	op = '=';
	options.clear();
}

bool LadyLogic::finish() {
	return (display == target);
}

Pad LadyLogic::encode(int edisplay, int ememory, char eop, bool eo, int steps) {
	Pad p;
	int tdc = 0;
	if(eo) tdc |= 1 << 31;
	tdc |= edisplay << 20;
	tdc |= ememory  << 8;
	tdc |= eop;
	p.code = tdc;
	p.steps = steps;
	return p;
}

void LadyLogic::decode(Pad pcode) {
	int code = pcode.code;
	o = (code >> 31) == 1;
	code &= 0x7fffffff;
	display = (code >> 20) & 0xfff;
	memory = (code >> 8) & 0xfff;
	op = code & 0xff;
	steps = pcode.steps;
}

bool LadyLogic::valid() {
	if(memory > 999 || memory < 0) return false;
	if(display > 999 || display < 0) return false;
	return true;
}

bool LadyLogic::visited(int pos) {
	//if(v[pos]) return true;
	//v[pos] = false;
	if(mset.count(pos)) return true;
	mset.insert(pos);
	return false;
}

int LadyLogic::eval(int a, char o, int b) {
	switch(o) {
		case '+': return a+b;
		case '-': return a-b;
		case '*': return a*b;
		case '/': return a/b;
		default:
			return b;	
	}
}

void LadyLogic::generateSuccessors() {
	for(int i = 0; i < (int)options.size(); i++) {
		switch(options[i]){
			case '0':
			case '1':
			case '2':
			case '3':
			case '4':
			case '5':
			case '6':
			case '7':
			case '8':
			case '9':
				if(!o){
					display = 10*display + options[i] - '0';
					myq.push(encode(display, memory, op, false,steps+1));
				} else {
					display = options[i] - '0';
					myq.push(encode(display, memory, op, false,steps+1));
				}
				break;
			default:
				if(o) {
					if(options[i]=='=' && op != '=')
						display = eval(memory, op, display);
					op = options[i];
					memory = display;
					myq.push(encode(display, memory, op, true,steps+1));
				} else {
					if(op != '=')
						display = eval(memory, op, display);
						op = options[i];
						memory = display;
						myq.push(encode(display, memory, op, true,steps+1));
				}
			break;
		}
	}
	

}

void LadyLogic::solve() {
	Pad p;
	while(!myq.empty()) {
		decode(p = myq.front());
		myq.pop();
		if(visited(p.code)) continue;
		if(!valid()) continue;
		if(finish()) break;
		generateSuccessors();
	}
	if(finish()) {
		printf("%d\n", steps);
	}
	printf("impossible\n");
}

bool LadyLogic::load() {
	reset();
	char c;
	while(scanf("%c", &c)==1) {
		
		if(c==' '){
			scanf("%d ", &target);
			myq.push(encode(display, memory, op, false,0));
			return true;
		} 
		options.push_back(c);
	}
	return false;
}

int main(int argc, char * argv[]) {
	LadyLogic l;
	while(l.load()) l.solve();
	return 0;
}
